#[non_exhaustive]pub enum ParseErrorKind {
InvalidLabel(String),
InvalidTime(String),
StartAfterEnd {
start: u64,
end: u64,
},
}Expand description
the specific kind of parse failure
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidLabel(String)
the line is empty or has invalid label syntax
InvalidTime(String)
a field that looked like a time could not be parsed as an integer
StartAfterEnd
the start time is greater than the end time